==> oktan-nautika-inti-gath-0.1.3-571b83.tar: src/Wp/Plugin/GathCategories.php <==
<?php
namespace Inti\Gath\Wp\Plugin;

use Inti\Gath\Model\Entity\Category;
use Inti\Gath\Model\Repository\CategoryRepository;
use Inti\Gath\Wp\ImageManager;
use WP_Term;
use WP_Term_Query;

/**
 * Class GathCategories
 *
 * @package Inti\Gath\Wp\Plugin
 * @author Danijel Fabijan <hipnaba@gmail.com>
 * @link https://bitbucket.org/oktan-nautika/inti-gath
 */
final class GathCategories extends GathTerms
{
    /** @var CategoryRepository */
    private $repo;
    /** @var ImageManager */
    private $images;
    /** @var string */
    protected $taxonomy = 'product_cat';
    /** @var string */
    protected $metaType = 'term';
    /** @var string[] */
    protected $metaKeys = [
        'thumbnail_id',
        'isTireCategory',
    ];

    /**
     * GathCategories constructor.
     * @param CategoryRepository $repo
     * @param ImageManager $images
     */
    public function __construct(CategoryRepository $repo, ImageManager $images)
    {
        $this->repo = $repo;
        $this->images = $images;
    }

    /**
     * @inheritDoc
     */
    public function init(): void
    {
        parent::init();

        add_filter('pre_option_product_cat_children', '__return_null');
        add_filter('pre_get_term', [$this, 'unhide_empty_categories']);
        add_filter('woocommerce_product_subcategories_hide_empty', [$this, 'unhide_empty_categories']);
    }

    /**
     * @inheritDoc
     */
    protected function get_metadata_by_id(int $objectId): array
    {
        if (!($category = $this->repo->getById(intval($objectId)))) {
            return [];
        }

        if ($category->getImage()) {
            if (get_option('gath_module_image_upload')) {
                $thumbnail_id = $this->images->getAttachmentIdByGathPath($category->getImage());
            } else {
                $thumbnail_id = sprintf('gath-%s', $category->getImage());
            }
        }

        return [
            'thumbnail_id' => $thumbnail_id ?? '',
            'isTireCategory' => $category->isTireCategory(),
        ];
    }

    /**
     * @param WP_Term_Query|bool $query
     * @return bool
     */
    public function unhide_empty_categories($query = null)
    {
        if ($query instanceof WP_Term_Query) {
            $query->query_vars['hide_empty'] = false;
        }

        return false;
    }

    /**
     * @param WP_Term_Query $query
     * @return WP_Term[]
     */
    protected function get_all_terms(WP_Term_Query $query): array
    {
        foreach ($this->repo->getAll() as $category) {
            $terms[] = $this->load_term($category);
        }

        return $terms ?? [];
    }

    /**
     * @param array $term_ids
     * @return WP_Term[]
     */
    protected function get_terms_by_id(array $term_ids): array
    {
        foreach ($this->repo->getByIds($term_ids) as $category) {
            $terms[] = $this->load_term($category);
        }

        return $terms ?? [];
    }

    /**
     * @param int $parent_id
     * @return WP_Term[]
     */
    protected function get_terms_by_parent_id(int $parent_id): array
    {
        foreach ($this->repo->getByParentId($parent_id) as $category) {
            $terms[] = $this->load_term($category);
        }

        return $terms ?? [];
    }

    /**
     * @param array $slugs
     * @return WP_Term[]
     */
    protected function get_terms_by_slug(array $slugs): array
    {
        foreach ($this->repo->getBySlugs($slugs) as $category) {
            $terms[] = $this->load_term($category);
        }

        return $terms ?? [];
    }

    /**
     * @param Category $category
     * @return WP_Term
     */
    private function load_term(Category $category): WP_Term
    {
        return new WP_Term((object) [
            'term_id' => $category->getId(),
            'name' => $category->getName(),
            'slug' => $category->getSlug(),
            'taxonomy' => 'product_cat',
            'description' => $category->getDescription() ?? '',
            'parent' => $category->getParentId(),
        ]);
    }
}

==> oktan-nautika-inti-gath-0.1.4-89103a.tar: src/Wp/Plugin/GathCategories.php <==
<?php
namespace Inti\Gath\Wp\Plugin;

use Inti\Gath\Model\Entity\Category;
use Inti\Gath\Model\Repository\CategoryRepository;
use Inti\Gath\Wp\ImageManager;
use WP_Term;
use WP_Term_Query;

/**
 * Class GathCategories
 *
 * @package Inti\Gath\Wp\Plugin
 * @author Danijel Fabijan <hipnaba@gmail.com>
 * @link https://bitbucket.org/oktan-nautika/inti-gath
 */
final class GathCategories extends GathTerms
{
    /** @var CategoryRepository */
    private $repo;
    /** @var ImageManager */
    private $images;
    /** @var string */
    protected $taxonomy = 'product_cat';
    /** @var string */
    protected $metaType = 'term';
    /** @var string[] */
    protected $metaKeys = [
        'thumbnail_id',
        'isTireCategory',
    ];

    /**
     * GathCategories constructor.
     * @param CategoryRepository $repo
     * @param ImageManager $images
     */
    public function __construct(CategoryRepository $repo, ImageManager $images)
    {
        $this->repo = $repo;
        $this->images = $images;
    }

    public function run(?array $options = null): void
    {
        parent::run($options);

        add_filter('pre_option_product_cat_children', '__return_null');
        add_filter('pre_get_term', [$this, 'unhide_empty_categories']);
        add_filter('woocommerce_product_subcategories_hide_empty', [$this, 'unhide_empty_categories']);
    }

    /**
     * @inheritDoc
     */
    protected function get_metadata_by_id(int $objectId): array
    {
        if (!($category = $this->repo->getById(intval($objectId)))) {
            return [];
        }

        if ($category->getImage()) {
            if (get_option('gath_module_image_upload')) {
                $thumbnail_id = $this->images->getAttachmentIdByGathPath($category->getImage());
            } else {
                $thumbnail_id = sprintf('gath-%s', $category->getImage());
            }
        }

        return [
            'thumbnail_id' => $thumbnail_id ?? '',
            'isTireCategory' => $category->isTireCategory(),
        ];
    }

    /**
     * @param WP_Term_Query|bool $query
     * @return bool
     */
    public function unhide_empty_categories($query = null): bool
    {
        if ($query instanceof WP_Term_Query) {
            $query->query_vars['hide_empty'] = false;
        }

        return false;
    }

    /**
     * @param WP_Term_Query $query
     * @return WP_Term[]
     */
    protected function get_all_terms(WP_Term_Query $query): array
    {
        foreach ($this->repo->getAll() as $category) {
            $terms[] = $this->load_term($category);
        }

        return $terms ?? [];
    }

    /**
     * @param array $term_ids
     * @return WP_Term[]
     */
    protected function get_terms_by_id(array $term_ids): array
    {
        foreach ($this->repo->getByIds($term_ids) as $category) {
            $terms[] = $this->load_term($category);
        }

        return $terms ?? [];
    }

    /**
     * @param int $parent_id
     * @return WP_Term[]
     */
    protected function get_terms_by_parent_id(int $parent_id): array
    {
        foreach ($this->repo->getByParentId($parent_id) as $category) {
            $terms[] = $this->load_term($category);
        }

        return $terms ?? [];
    }

    /**
     * @param array $slugs
     * @return WP_Term[]
     */
    protected function get_terms_by_slug(array $slugs): array
    {
        foreach ($this->repo->getBySlugs($slugs) as $category) {
            $terms[] = $this->load_term($category);
        }

        return $terms ?? [];
    }

    /**
     * @param Category $category
     * @return WP_Term
     */
    private function load_term(Category $category): WP_Term
    {
        return new WP_Term((object) [
            'term_id' => $category->getId(),
            'name' => $category->getName(),
            'slug' => $category->getSlug(),
            'taxonomy' => 'product_cat',
            'description' => $category->getDescription() ?? '',
            'parent' => $category->getParentId(),
        ]);
    }
}
